//  Created by Robin Speijer on 19-05-17.
//  Copyright © 2017 Bohemian Coding. 

/// The error domain for all errors that are generated by SketchCloudKit.
static NSString * const _Nonnull SCKErrorDomain = @"com.bohemiancoding.cloudkit.error";
static NSString * const _Nonnull SCKKeychainErrorDomain = @"com.bohemiancoding.cloudkit.keychain.error";
/// Domain for any error that has been thrown by the GraphQL API. Must match the Swift generated error domain for the GraphAPIError struct.
static NSString * const _Nonnull SCKGraphAPIErrorDomain = @"SketchCloudKit.GraphAPIError";
static NSString * const _Nonnull SCKAPIEnvironmentErrorKey = @"environment";

typedef NSInteger SCKErrorCode NS_TYPED_EXTENSIBLE_ENUM;
static SCKErrorCode const SCKErrorCodeNoContent = 204;
static SCKErrorCode const SCKErrorCodeNotFound = 404;
static SCKErrorCode const SCKErrorCodeInvalidFormat = 601;
static SCKErrorCode const SCKErrorCodeInvalidContent DEPRECATED_MSG_ATTRIBUTE("Replaced by `SCKErrorCodeNotFound`.") = 602;
static SCKErrorCode const SCKErrorCodeInvalidRequest = 400;
static SCKErrorCode const SCKErrorCodeResponseNotMockable = 701;
static SCKErrorCode const SCKErrorCodeDataNotMockable = 702;

@interface NSError (Cloud)

/// Checks if the given response + data represents a server error. If this is the case, the error is constructed and returned.
+ (nullable NSError *)errorFromAPIResponse:(nullable NSURLResponse *)response data:(nullable NSData *)data;

/// Whether this is a Sketch Cloud related error.
@property (nonatomic, readonly) BOOL isCloudError;

/// Whether this is a Cloud error that has been thrown because the requester is not authorized to access the resource.
@property (nonatomic, readonly) BOOL isCloudUnauthorized;

/// Whether this is a Cloud error that has been thrown because the requested resource is forbidden to access.
@property (nonatomic, readonly) BOOL isCloudForbidden;

/// Whether the error is a result of cancelling the original URL request.
@property (nonatomic, readonly) BOOL isUrlCancelled;

/// A Cloud API error could theoretically contain child errors with additional information about the error. This is usually meant for HTTP forms, and separate messages are required for separate fields of information.
@property (nonatomic, nullable, readonly) NSArray<NSDictionary *> *fields;

@end
